@@ -1,6 +1,8 @@
 """Query client library."""
 
 from socket import SOCK_DGRAM, socket
+from typing import Optional, Union
+from warnings import warn
 
 from mcipc.query.proto import BasicStats
 from mcipc.query.proto import BasicStatsRequest
@@ -14,6 +16,20 @@ from mcipc.query.proto import Response
 __all__ = ['Client']
 
 
+WARN_TEMP = 'Client.{} is deprecated. Use Client.stats({}) instead.'
+BasicMessages = tuple[BasicStatsRequest, BasicStats]
+FullMessages = tuple[FullStatsRequest, FullStats]
+
+
+def get_message_types(full: bool) -> Union[BasicMessages, FullMessages]:
+    """Returns request and response types."""
+
+    if full:
+        return (FullStatsRequest, FullStats)
+
+    return (BasicStatsRequest, BasicStats)
+
+
 class Client:
     """A basic client, common to Query and RCON."""
 
@@ -25,42 +41,50 @@ class Client:
         self.timeout = timeout
         self.challenge_token = None
 
-    def __enter__(self):
-        """Conntects the socket."""
+    def connect(self) -> None:
+        """Contects the socket."""
         self._socket.__enter__()
-        self._socket.settimeout(self.timeout)
         self._socket.connect((self.host, self.port))
 
         if self.challenge_token is None:
             self.challenge_token = self.handshake()
 
+    def disconnect(self) -> Optional[bool]:
+        """Delegates to the underlying socket's exit method."""
+        self.challenge_token = None
+        return self._socket.__exit__()
+
+    def __enter__(self):
+        """connect on entering a context"""
+        self.connect()
         return self
 
-    def __exit__(self, typ, value, traceback):
+    def __exit__(self, *_):
         """Delegates to the underlying socket's exit method."""
-        return self._socket.__exit__(typ, value, traceback)
+        return self.disconnect()
+
+    @property
+    def timeout(self) -> float:
+        """Returns the socket timeout."""
+        return self._socket.gettimeout()
+
+    @timeout.setter
+    def timeout(self, timeout: float):
+        """Sets the socket timeout."""
+        self._socket.settimeout(timeout)
 
     @property
     def basic_stats(self) -> BasicStats:
-        """Returns basic stats"""
-        request = BasicStatsRequest.create(self.challenge_token)
-
-        with self._socket.makefile('wb') as file:
-            file.write(bytes(request))
-
-        with self._socket.makefile('rb') as file:
-            return BasicStats.read(file)
+        """Returns basic stats."""
+        warn(WARN_TEMP.format('basic_stats', ''), FutureWarning, stacklevel=2)
+        return self.stats()
 
     @property
     def full_stats(self) -> FullStats:
-        """Returns full stats"""
-        request = FullStatsRequest.create(self.challenge_token)
-
-        with self._socket.makefile('wb') as file:
-            file.write(bytes(request))
-
-        with self._socket.makefile('rb') as file:
-            return FullStats.read(file)
+        """Returns full stats."""
+        warn(WARN_TEMP.format('full_stats', 'full=True'), FutureWarning,
+             stacklevel=2)
+        return self.stats(full=True)
 
     def handshake(self) -> BigEndianSignedInt32:
         """Performs a handshake."""
@@ -73,3 +97,14 @@ class Client:
             response = Response.read(file)
 
         return response.challenge_token
+
+    def stats(self, full: bool = False) -> Union[BasicStats, FullStats]:
+        """Returns basic or full stats."""
+        request_type, return_type = get_message_types(full)
+        request = request_type.create(self.challenge_token)
+
+        with self._socket.makefile('wb') as file:
+            file.write(bytes(request))
+
+        with self._socket.makefile('rb') as file:
+            return return_type.read(file)
