@@ -11,9 +11,10 @@ from typing import IO, Iterable, Iterator, Union
 __all__ = [
     'MAGIC',
     'NULL',
-    'decodeall',
+    'decode_all',
     'ip_or_hostname',
     'random_session_id',
+    'BigEndianSignedInt32',
     'IPAddressOrHostname',
     'Type'
 ]
@@ -27,7 +28,7 @@ SESSION_ID_MASK = 0x0F0F0F0F
 IPAddressOrHostname = Union[IPv4Address, IPv6Address, str]
 
 
-def decodeall(blocks: Iterable[bytes], encoding='latin-1') -> Iterator[str]:
+def decode_all(blocks: Iterable[bytes], encoding='latin-1') -> Iterator[str]:
     """Decodes all byte blocks with the given encoding."""
 
     return map(partial(bytes.decode, encoding=encoding), blocks)
@@ -70,8 +71,8 @@ class BigEndianSignedInt32(int):
 
     @classmethod
     def from_bytes(cls, bytes_: bytes) -> BigEndianSignedInt32:
-        """Reutns the int from the given bytes."""
-        return super().from_bytes(bytes_, 'big', signed=True)
+        """Returns the int from the given bytes."""
+        return cls(super().from_bytes(bytes_, 'big', signed=True))
 
     @classmethod
     def read(cls, file: IO) -> BigEndianSignedInt32:
@@ -79,15 +80,15 @@ class BigEndianSignedInt32(int):
         return cls.from_bytes(file.read(4))
 
 
-class Type(Enum):
+class Type(int, Enum):
     """Request type."""
 
     HANDSHAKE = 9
     STAT = 0
 
     def __bytes__(self):
-        """Reuturns the integer value as big endian."""
-        return self.value.to_bytes(1, 'big')    # pylint: disable=E1101
+        """Returns the integer value as big endian."""
+        return self.value.to_bytes(1, 'big')
 
     @classmethod
     def from_bytes(cls, bytes_: bytes) -> Type:
