@@ -5,6 +5,7 @@ from contextlib import suppress
 from typing import IO, NamedTuple
 
 from mcipc.query.proto.common import MAGIC
+from mcipc.query.proto.common import NULL
 from mcipc.query.proto.common import random_session_id
 from mcipc.query.proto.common import BigEndianSignedInt32
 from mcipc.query.proto.common import Type
@@ -43,15 +44,15 @@ class Response(NamedTuple):
     @classmethod
     def read(cls, file: IO) -> Response:
         """Reads the response from a file-like object."""
-        type_ = Type.from_bytes(file.read(1))
-        session_id = BigEndianSignedInt32.from_bytes(file.read(4))
+        type_ = Type.read(file)
+        session_id = BigEndianSignedInt32.read(file)
         # For challenge token, see: https://wiki.vg/Query#Handshake
         bytes_ = b''
 
         while True:
             byte = file.read(1)
 
-            if byte == b'\x00':
+            if byte == NULL:
                 with suppress(ValueError):
                     challenge_token = BigEndianSignedInt32(bytes_.decode())
                     break
