@@ -1,6 +1,6 @@
 """Implementation of the gamemode command."""
 
-from typing import Union
+from typing import Optional, Union
 
 from mcipc.rcon.client import Client
 from mcipc.rcon.types import GameMode
@@ -9,8 +9,11 @@ from mcipc.rcon.types import GameMode
 __all__ = ['gamemode']
 
 
-def gamemode(self: Client, mode: Union[GameMode, int],
-             target: str = None) -> str:
+def gamemode(
+        self: Client,
+        mode: Union[GameMode, int],
+        target: Optional[str] = None
+) -> str:
     """Sets the game mode."""
 
     return self.run('gamemode', mode, target)
