@@ -1,5 +1,7 @@
 """Implementation of the playsound command."""
 
+from typing import Optional
+
 from mcipc.rcon.client import Client
 from mcipc.rcon.types import Vec3
 
@@ -8,9 +10,14 @@ __all__ = ['playsound']
 
 
 # pylint: disable=R0913
-def playsound(self: Client, sound: str, player: str = None,
-              position: Vec3 = None, volume: float = None,
-              minimum_volume: float = None) -> str:
+def playsound(
+        self: Client,
+        sound: str,
+        player: Optional[str] = None,
+        position: Optional[Vec3] = None,
+        volume: Optional[float] = None,
+        minimum_volume: Optional[float] = None
+) -> str:
     """Plays a sound."""
 
     return self.run('playsound', sound, player, position, volume,
