@@ -1,5 +1,7 @@
 """Implementation of the spawnpoint command."""
 
+from typing import Optional
+
 from mcipc.rcon.client import Client
 from mcipc.rcon.types import Vec3
 
@@ -7,8 +9,11 @@ from mcipc.rcon.types import Vec3
 __all__ = ['spawnpoint']
 
 
-def spawnpoint(self: Client, player: str = None,
-               spawn_pos: Vec3 = None) -> str:
+def spawnpoint(
+        self: Client,
+        player: Optional[str] = None,
+        spawn_pos: Optional[Vec3] = None
+) -> str:
     """Sets the spawn point for a player."""
 
     return self.run('spawnpoint', player, spawn_pos)
