@@ -1,5 +1,7 @@
 """Implementation of the setblock command."""
 
+from typing import Optional
+
 from mcipc.rcon.client import Client
 from mcipc.rcon.types import SetblockMode, Vec3
 
@@ -7,8 +9,12 @@ from mcipc.rcon.types import SetblockMode, Vec3
 __all__ = ['setblock']
 
 
-def setblock(self: Client, pos: Vec3, block: str,
-             mode: SetblockMode = None) -> str:
+def setblock(
+        self: Client,
+        pos: Vec3,
+        block: str,
+        mode: Optional[SetblockMode] = None
+) -> str:
     """Sets a block."""
 
     return self.run('setblock', pos, block, mode)
