@@ -1,5 +1,7 @@
 """Implementation of the team command."""
 
+from typing import Optional
+
 from mcipc.rcon.client import Client
 from mcipc.rcon.je.types import TeamOption, TeamValue
 from mcipc.rcon.proxy import CommandProxy
@@ -12,7 +14,7 @@ class TeamProxy(CommandProxy):
     """Proxy for team commands."""
 
     # pylint: disable=W0621
-    def add(self, team: str, display_name: dict = None) -> str:
+    def add(self, team: str, display_name: Optional[dict] = None) -> str:
         """Adds a team."""
         return self._run('add', team, display_name)
 
@@ -20,15 +22,15 @@ class TeamProxy(CommandProxy):
         """Emties a team."""
         return self._run('empty', team)
 
-    def join(self, team: str, members: str = None) -> str:
+    def join(self, team: str, members: Optional[str] = None) -> str:
         """Joins a team."""
         return self._run('join', team, members)
 
-    def leave(self, members: str = None) -> str:
+    def leave(self, members: Optional[str] = None) -> str:
         """Leaves the team."""
         return self._run('leave', members)
 
-    def list(self, team: str = None) -> str:
+    def list(self, team: Optional[str] = None) -> str:
         """Lists team members."""
         return self._run('list', team)
 
