@@ -1,17 +1,19 @@
 """Locations."""
 
 from re import fullmatch
-from typing import NamedTuple, Union
+from typing import NamedTuple, Optional
 
 from mcipc.functions import json_serializable
-from mcipc.rcon.errors import LocationNotFound
+from mcipc.rcon.exceptions import LocationNotFound
 
 
 __all__ = ['Location', 'parse']
 
 
-REGEX = ('The nearest (.+) is at \\[(-?\\d+), (~|-?\\d+), '
-         '(-?\\d+)\\] \\((\\d+) block[s]? away\\)')
+REGEX = (
+    r'The nearest (.+) is at \[(-?\d+), (~|-?\d+), '
+    r'(-?\d+)\] \((\d+) block[s]? away\)'
+)
 
 
 @json_serializable
@@ -20,7 +22,7 @@ class Location(NamedTuple):
 
     name: str
     x: int
-    y: Union[int, None]
+    y: Optional[int]
     z: int
     distance: int
 
